@@ -17,39 +17,39 @@ class BaseGraph():
     _default_formatting = {
         'margin_left': 50,
         'margin_right': 50,
-        'margin_top': 50,
-        'margin_bottom': 50,
+        'margin_year_max': 5,
+        'margin_year_min': 10,
         'vertical_step_size': 40,
-        'relative_line_thickness': 0.5,
-        'total_height': 2000,
+        'relative_line_thickness': 0.4,
+        'total_height': 1500,
         'display_factor': -1,
         'font_size_description': 0.7,
         'font_description_letter_offset': [str(30 / 12.0)],
         'font_name': 'Arial',
         'birth_label_active': True,
         'birth_label_along_path': False,
-        'birth_label_rotation': -90,
-        'birth_label_anchor': 'start',
-        'birth_label_wrapping_active': False,
-        'birth_label_letter_x_offset': 0.8,
-        'birth_label_letter_y_offset': 0,
+        'birth_label_rotation': 0,
+        'birth_label_anchor': 'middle',
+        'birth_label_wrapping_active': True,
+        'birth_label_letter_x_offset': 0,
+        'birth_label_letter_y_offset': 1,
         'fade_individual_color': True,
-        'fade_individual_color_black_age': 150,
-        'marriage_label_active': True,
+        'fade_individual_color_black_age': 200,
+        'marriage_label_active': False,
         'no_ring': False,
         'death_label_active': True,
-        'death_label_rotation': -90,
-        'death_label_anchor': 'start',
-        'death_label_wrapping_active': False,
-        'death_label_letter_x_offset': 0.8,
-        'death_label_letter_y_offset': 0,
+        'death_label_rotation': 0,
+        'death_label_anchor': 'middle',
+        'death_label_wrapping_active': True,
+        'death_label_letter_x_offset': 0,
+        'death_label_letter_y_offset': -1,
         'warp_shape': 'normal',
         'family_shape': 0,
-        'individual_foto_active': False,
-        'individual_foto_relative_size': 2.5
+        'individual_photo_active': False,
+        'individual_photo_relative_size': 2.5
     }
     _default_positioning = {
-        'generations': 4,
+        'generations': 5,
         'compression_steps': -1,  # debugging option
         'compress': False,
         'flip_to_optimize': False,
@@ -65,13 +65,13 @@ class BaseGraph():
                 'triangle': 'Triangular shape'
             }
         },
-        'individual_foto_active': {
-            'short_description': 'Show fotos',
-            'long_description': 'Fotos of the individual are shown.'
+        'individual_photo_active': {
+            'short_description': 'Show photos',
+            'long_description': 'Photos of the individual are shown.'
         },
-        'individual_foto_relative_size': {
-            'short_description': 'Foto size',
-            'long_description': 'Fotos which are shown are fitted into a square of this extent. The size is given relative to the line thickness.'
+        'individual_photo_relative_size': {
+            'short_description': 'Photo size',
+            'long_description': 'Photos which are shown are fitted into a square of this extent. The size is given relative to the line thickness.'
         },
         'total_height': {
             'short_description': 'Total height',
@@ -184,6 +184,14 @@ class BaseGraph():
                 1 : 'Softer'
             }
         },
+        'margin_year_max': {
+            'short_description': 'Upper year minimum margin',
+            'long_description': 'The upper bound of the chart is extended by at least this number of years.'
+        },
+        'margin_year_min': {
+            'short_description': 'Lower year minimum margin',
+            'long_description': 'The lower bound of the chart is extended by at least this number of years.'
+        }
     }
     _positioning_description = {
         'generations': {
@@ -225,12 +233,15 @@ class BaseGraph():
         self._instances[('i', None)] = None
         self.graphical_individual_representations = []
         self.graphical_family_representations = []
+        self.additional_graphical_items = {}
         logger.debug('finished creating instances')
 
         self.min_x_index = 10000000
         self.max_x_index = -10000000
-        self.min_ordinal = 10000000
-        self.max_ordinal = -10000000
+        self.min_ordinal = None
+        self.max_ordinal = None
+        self.chart_min_ordinal = None
+        self.chart_max_ordinal = None
 
     def get_default_formatting_and_description(self):
         return deepcopy(self._default_formatting), deepcopy(self._formatting_description)
@@ -273,7 +284,7 @@ class BaseGraph():
             ancestor_graph_inidividual: created instance
         """
         new_instance = self._graphical_individual_class(
-            self._instances, individual.individual_id, self._formatting['vertical_step_size'])
+            self._instances, individual.individual_id)
         if new_instance.birth_date is None or new_instance.death_date is None:
             del new_instance
             return None
@@ -423,13 +434,15 @@ class BaseGraph():
             return
         husb_x_pos = family.husb.graphical_representations[0].get_x_position()[
             family.family_id][1]
-        husb_width = family.graphical_representations[0].husb_width
+        husb_width = family.graphical_representations[0].husb_width()
         wife_x_pos = family.wife.graphical_representations[0].get_x_position()[
             family.family_id][1]
-        wife_width = family.graphical_representations[0].wife_width
+        wife_width = family.graphical_representations[0].wife_width()
         children_width = family.graphical_representations[0].children_width
         if not children_width:
             children_width = self._formatting['vertical_step_size']
+        if children_width != len(family.graphical_representations[0].visible_children):
+            print("G")
 
         if husb_x_pos < wife_x_pos:
             husb_x_delta = wife_width + children_width
@@ -450,6 +463,7 @@ class BaseGraph():
             family.husb, family, husb_x_delta+1000000)
         self._move_individual_and_ancestors(family.wife, family, wife_x_delta)
         self._move_individual_and_ancestors(family.husb, family, -1000000)
+        self._instances.ancestor_width_cache.clear()
         pass
 
     def _check_compressed_x_position(self, early_raise):
@@ -485,15 +499,13 @@ class BaseGraph():
                     v[x_index] = []
                     position_to_person_map[x_index] = []
                 if i == 0:
-                    start_y = graphical_individual_representation.get_birth_event()[
-                        'ordinal_value']
+                    start_y = graphical_individual_representation.get_birth_date_ov()
                 else:
                     start_y = list(x_pos.values())[i][0]
                 if i < len(x_pos) - 1:
                     end_y = list(x_pos.values())[i+1][0]
                 else:
-                    end_y = graphical_individual_representation.get_death_event()[
-                        'ordinal_value']
+                    end_y = graphical_individual_representation.get_death_date_ov()
                 position_to_person_map[x_index].append({
                     'start': start_y,
                     'end': end_y,
@@ -510,14 +522,10 @@ class BaseGraph():
         for x_index, graphical_individual_representation_list in v.items():
             for index, graphical_individual_representation_a in enumerate(graphical_individual_representation_list):
                 for graphical_individual_representation_b in graphical_individual_representation_list[index+1:]:
-                    birth_position_a = graphical_individual_representation_a.get_birth_event()[
-                        'ordinal_value'] - 365*15
-                    birth_position_b = graphical_individual_representation_b.get_birth_event()[
-                        'ordinal_value'] - 365*15
-                    death_position_a = graphical_individual_representation_a.get_death_event()[
-                        'ordinal_value'] + 365*15
-                    death_position_b = graphical_individual_representation_b.get_death_event()[
-                        'ordinal_value'] + 365*15
+                    birth_position_a = graphical_individual_representation_a.get_birth_date_ov() - 365*15
+                    birth_position_b = graphical_individual_representation_b.get_birth_date_ov() - 365*15
+                    death_position_a = graphical_individual_representation_a.get_death_date_ov() + 365*15
+                    death_position_b = graphical_individual_representation_b.get_death_date_ov() + 365*15
                     if ((birth_position_a - birth_position_b)
                                 * (birth_position_a - death_position_b) < 0 or
                                 (death_position_a - birth_position_b)
@@ -592,12 +600,11 @@ class BaseGraph():
             float: y position
         """
         return (
-            self._formatting['margin_top']
-            - self._formatting['total_height'] *
-            (self._formatting['display_factor']-1)/2
-            + (ordinal_value - self.min_ordinal)/(self.max_ordinal-self.min_ordinal) *
+            + (ordinal_value - self.chart_min_ordinal)/(self.chart_max_ordinal-self.chart_min_ordinal) *
             self._formatting['total_height'] *
             self._formatting['display_factor']
+            - self._formatting['total_height'] *
+            (self._formatting['display_factor']-1)/2
         )
 
     def _map_x_position(self, x_index):
@@ -661,13 +668,33 @@ class BaseGraph():
 
         return angle_deg
 
+    def _inverse_y_delta(self, delta_y):
+        """
+        map back a delta display size to the delta ordinal value
+
+        Args:
+            delta_y (float): difference of display size
+
+        Returns:
+            float: difference of ordinal value
+        """
+        return delta_y / (self._formatting['total_height'] * self._formatting['display_factor']) * (self.max_ordinal-self.min_ordinal)
+
     def _inverse_y_position(self, pos_y):
+        """
+        map back a display position to an ordinal value
+
+        Args:
+            pos_y (float): display position
+
+        Returns:
+            float: ordinal value
+        """
         return (
             pos_y
-            - self._formatting['margin_top']
             + self._formatting['total_height'] *
             (self._formatting['display_factor']-1)/2
-        ) / (self._formatting['total_height'] * self._formatting['display_factor']) * (self.max_ordinal-self.min_ordinal) + self.min_ordinal
+        ) / (self._formatting['total_height'] * self._formatting['display_factor']) * (self.chart_max_ordinal-self.chart_min_ordinal) + self.chart_min_ordinal
 
     def _inverse_x_position(self, pos_x):
         return int(round((pos_x - self._formatting['margin_left'])/self._formatting['vertical_step_size']))
@@ -688,7 +715,7 @@ class BaseGraph():
         Returns:
             float: graph height
         """
-        return abs(self._map_y_position(self.min_ordinal) - self._map_y_position(self.max_ordinal)) + self._formatting['margin_bottom']
+        return abs(self._map_y_position(self.chart_min_ordinal) - self._map_y_position(self.chart_max_ordinal))
 
     def get_individual_from_position(self, pos_x, pos_y):
         """
@@ -714,8 +741,9 @@ class BaseGraph():
         """
         clear all graphical representations to rebuild the chart
         """
-        self.additional_graphical_items = {}
-        self.additional_graphical_items['grid'] = []
+        self.max_ordinal = None
+        self.min_ordinal = None
+        self.additional_graphical_items.clear()
         self.graphical_individual_representations.clear()
         self.graphical_family_representations.clear()
         for key, instance in self._instances.items():
