@@ -14,11 +14,26 @@ class InstanceContainer():
     Container class for all kinds of instances. This class reads the database.
     """
 
+    date_label_translation = {
+        'Calculated': '{symbol}\xa0berechnet\xa0{date}',
+        'Estimated': '{symbol}\xa0geschätzt\xa0{date}',
+        'Estimated (min 25 at marriage)': '{symbol}\xa0geschätzt\xa0{date}',
+        'Estimated (max age 75)': '{symbol}\xa0geschätzt\xa0{date}',
+        'Estimated (max age 100)': '{symbol}\xa0geschätzt\xa0{date}',
+        'Estimated (min 1 after parents marriage)': '{symbol}\xa0geschätzt\xa0{date}',
+        'Still alive': '',
+        'About': '{symbol}\xa0etwa\xa0{date}',
+        'Before': '{symbol}\xa0vor\xa0{date}',
+        'After': '{symbol}\xa0nach\xa0{date}',
+        'YearPrecision': '{symbol}\xa0{date}'
+    }
+
     def __init__(self, family_constructor, individual_constructor, instantiate_all):
         self._data = {('i', None): None, ('f', None): None}
         self._family_constructor = family_constructor
         self._individual_constructor = individual_constructor
         self.instantiate_all = instantiate_all
+        self.ancestor_width_cache = {}
 
     def __iter__(self):  # iterate over all keys
         for type_id, instance in self._data.keys():
@@ -66,7 +81,7 @@ class InstanceContainer():
     def clear(self):
         """
         clear all data
-        """        
+        """
         self._data.clear()
         self._data.update({('i', None): None, ('f', None): None})
 
